@@ -3,7 +3,7 @@
 #--------------------------------------------------------------------#
 # This file is part of Py-notify.                                    #
 #                                                                    #
-# Copyright (C) 2006, 2007 Paul Pogonyshev.                          #
+# Copyright (C) 2006, 2007, 2008 Paul Pogonyshev.                    #
 #                                                                    #
 # This library is free software; you can redistribute it and/or      #
 # modify it under the terms of the GNU Lesser General Public License #
@@ -1271,11 +1271,13 @@ class CleanSignal (Signal):
         """
 
         if self.__parent is not None:
+            # Note that we must clear `__parent' first, because call to unprotect() below
+            # can invoke our collect_garbage() which might then call unprotect() once more
+            # (i.e. one time too many in result).
+            self.__parent = None
             if self._handlers is not None:
                 AbstractGCProtector.default.unprotect (self)
 
-            self.__parent = None
-
     def __orphan (self, reference = None):
         self.orphan ()
 
@@ -1332,7 +1334,8 @@ class CleanSignal (Signal):
 
             if not self._handlers:
                 self._handlers = None
-                AbstractGCProtector.default.unprotect (self)
+                if self.__parent is not None:
+                    AbstractGCProtector.default.unprotect (self)
 
 
     def _additional_description (self, formatter):
